import { Button, Checkbox, Space } from 'antd'
import React, { useEffect, useState } from 'react'
import { useLocation, useNavigate } from 'react-router-dom'
import styled from 'styled-components'
import { getOnceJoblog } from '../services/index'

const LogWrapper = styled.div`
  margin: 20px;
  padding: 30px;
  background-color: #fff;
  .log {
    background-color: #012b36;
    height: calc(100vh - 200px);
    overflow-y: scroll;
    color: #638691;
    padding: 8px 10px;
    ::-webkit-scrollbar {
      display: none;
    }
  }
  .return {
    display: flex;
    justify-content: flex-end;
    padding-bottom: 10px;
  }
`

let timeout = null

const LogWatcher = () => {
  const navigate = useNavigate()
  const { state } = useLocation()
  const [logData, setLogData] = useState(null)
  const [autoRefresh, setAutoRefresh] = useState(false)

  const fetchOnceJoblog = async () => {
    const { data } = await getOnceJoblog(state.id)
    if (data.code === 200) {
      setLogData(data.data.log)
      if (![2, 3].includes(data.data.status) && autoRefresh) {
        timeout = setTimeout(() => {
          fetchOnceJoblog()
        }, 5000)
      }
    }
  }
  useEffect(() => {
    fetchOnceJoblog()
  }, [state])

  const returnLogTable = () => {
    navigate('/datasource', {
      state: {
        key: '3',
        currentPage: state.currentPage,
        currentPageSize: state.currentPageSize,
        logId: state.logId,
      },
    })
  }

  const changeRefresh = e => {
    if (e.target.checked) {
      fetchOnceJoblog()
    } else {
      clearTimeout(timeout)
    }
    setAutoRefresh(e.target.checked)
  }

  const onClickRefresh = () => {
    fetchOnceJoblog()
  }

  return (
    <LogWrapper>
      <div className="return">
        <Space>
          <Checkbox onChange={changeRefresh} checked={autoRefresh}>
            自动刷新
          </Checkbox>
          <Button onClick={onClickRefresh}>刷新</Button>
          <Button
            type="primary"
            onClick={() => {
              returnLogTable()
            }}>
            返回上一级
          </Button>
        </Space>
      </div>
      <pre className="log">{logData}</pre>
    </LogWrapper>
  )
}

export default LogWatcher
