import React, { useMemo, useState } from 'react'
import { Form, Select, Input, DatePicker, Row, Col, InputNumber } from 'antd'
import CronSelect from '../../../component/CronSelect'

const FormItem = Form.Item

export default function StepFour({
  onRef,
  syncDataForm,
  partitionNumHandle,
  cron_data,
}) {
  // 是否展示分区时间
  const [showPartitionTime, setShowPartitionTime] = useState(false)
  const [cronData, setCronData] = useState(null)
  const [partitionNum, setPartitionNum] = useState(null)
  useState(() => {
    setCronData(syncDataForm.getFieldValue('cron_expression'))
    if (syncDataForm.getFieldValue('partition_info')) {
      setShowPartitionTime(true)
    }
  }, [])
  useMemo(() => {
    setCronData(cron_data)
    if (syncDataForm.getFieldValue('partition_info')) {
      setShowPartitionTime(true)
    }
  }, [cron_data])
  useState(() => {
    if (partitionNumHandle.num !== null) {
      setPartitionNum(partitionNumHandle.num)
    }
  }, [partitionNumHandle.num])
  const onPartitionNumChange = val => {
    setPartitionNum(val)
    partitionNumHandle.func(val)
  }
  return (
    <div>
      <p
        style={{
          fontWeight: 600,
          borderLeft: '3px solid #1881DA',
          paddingLeft: '12px',
        }}>
        设置同步参数
      </p>
      <Form
        name="syncForm"
        form={syncDataForm}
        labelCol={{
          span: 2,
        }}
        wrapperCol={{
          span: 8,
        }}
        initialValues={{
          partition_info: '',
          executor_timeout: 0,
          executor_fail_retry_count: 0,
          inc_start_time: '',
        }}>
        <FormItem
          label="同步任务名称"
          name="job_desc"
          rules={[
            {
              required: true,
              message: '请输入同步任务名',
            },
          ]}>
          <Input placeholder="请输入同步任务名称" />
        </FormItem>
        <FormItem
          label="路由策略"
          name="executor_route_strategy"
          rules={[
            {
              required: true,
              message: '请选择路由策略',
            },
          ]}>
          <Select
            options={[
              { label: '第一个', value: 'FIRST' },
              { label: '最后一个', value: 'LAST' },
            ]}
            allowClear
            placeholder="请选择路由策略"
          />
        </FormItem>
        <FormItem
          label="阻塞处理方式"
          name="executor_block_strategy"
          rules={[
            {
              required: true,
              message: '请选择阻塞处理方式',
            },
          ]}>
          <Select
            options={[
              { label: '单机串行', value: 'SERIAL_EXECUTION' },
              { label: '丢弃后续调度', value: 'SERIAL_EXECUTION1' },
              { label: '覆盖之前调度', value: 'SERIAL_EXECUTION2' },
            ]}
            allowClear
            placeholder="请选择阻塞处理方式"
          />
        </FormItem>
        <FormItem
          label="定时规则"
          name="cron_expression"
          rules={[
            {
              required: true,
              message: '请选择定时规则',
            },
          ]}>
          <CronSelect cron_data={cronData} ref={onRef} />
        </FormItem>
        <FormItem
          label="超时时间"
          name="executor_timeout"
          rules={[
            {
              required: true,
              message: '请输入超时时间',
            },
          ]}>
          <InputNumber min={0} addonAfter="分钟" />
        </FormItem>
        <FormItem
          label="失败重试次数"
          name="executor_fail_retry_count"
          rules={[
            {
              required: true,
              message: '请输入失败重试次数',
            },
          ]}>
          <InputNumber min={0} addonAfter="次" />
        </FormItem>
        <FormItem label="增量开始时间" name="inc_start_time">
          <DatePicker showTime placeholder="请选择增量开始时间" />
        </FormItem>
        <FormItem label="上次执行时间" name="last_time">
          <Input placeholder="lastTime" />
        </FormItem>
        <FormItem label="本次执行时间" name="current_time">
          <Input placeholder="currentTime" />
        </FormItem>
        <Row span={24}>
          <Col span={8}>
            <FormItem
              label="分区字段"
              name="partition_info"
              labelCol={{
                span: 6,
              }}
              wrapperCol={{
                span: 12,
              }}>
              <Input
                onChange={e => {
                  if (e.target.value && !showPartitionTime) {
                    setShowPartitionTime(true)
                  } else if (!e.target.value && showPartitionTime) {
                    setShowPartitionTime(false)
                  }
                }}
                placeholder="请输入分区字段"
              />
            </FormItem>
          </Col>
          {showPartitionTime ? (
            <>
              <Col span={4}>
                <FormItem
                  label="分区时间"
                  name="partition_time"
                  labelCol={{
                    span: 12,
                  }}
                  wrapperCol={{
                    span: 12,
                  }}>
                  <Select
                    options={[
                      { label: '%Y-%m-%d', value: '%Y-%m-%d' },
                      { label: '%Y%m%d', value: '%Y%m%d' },
                      { label: '%Y/%m/%d', value: '%Y/%m/%d' },
                    ]}
                    allowClear
                    onSelect={val =>
                      syncDataForm.setFieldValue('partition_time', val)
                    }
                  />
                </FormItem>
              </Col>
              <Col>
                <InputNumber
                  value={partitionNum}
                  onChange={onPartitionNumChange}
                  style={{ marginLeft: '10px' }}
                  max={0}
                  min={-20}
                />
              </Col>
            </>
          ) : (
            ''
          )}
        </Row>
        <FormItem label="JVM启动参数" name="jvm_param">
          <Input placeholder="-Xms1024m -Xmx1024m -XX:+HeapDumpOnOutOfMemoryError" />
        </FormItem>
      </Form>
    </div>
  )
}
