import { Tabs, Button } from 'antd'
import DataSourceManage from '../component/DatasourceManage.jsx'
import DatasourceAdd from '../component/DatasourceAdd'
import DatasourceSyncView from '../component/DatasourceSyncView'
import DatasourceLog from '../component/DatasourceLog'
import React, { useState } from 'react'
import { Link, useNavigate, useLocation } from 'react-router-dom'
import styled from 'styled-components'
import { useEffect } from 'react'
const { TabPane } = Tabs

const Datasource = styled.div`
  padding: 20px;
`

export default function DatasourceView() {
  const navigate = useNavigate()
  const { state } = useLocation()
  // 数据源管理ref
  const sourceRef = React.createRef()
  const logRef = React.createRef()
  // 当前所处页面
  const [currentKey, setCurrentKey] = useState('1')
  const [currentLog, setCurrentLog] = useState(null)
  const [currentSyncPage, setCurrentSyncPage] = useState(1)
  const [currentSyncPageSize, setCurrentSyncPageSize] = useState(10)
  const [currentLogPage, setCurrentLogPage] = useState(1)
  const [currentLogPageSize, setCurrentLogPageSize] = useState(10)

  useEffect(() => {
    if (state) {
      setCurrentKey(state.key)
      if (state.key === '2') {
        setCurrentSyncPage(state.currentPage)
        setCurrentSyncPageSize(state.currentPageSize)
      } else if (state.key === '3') {
        setCurrentLogPage(state.currentPage)
        setCurrentLogPageSize(state.currentPageSize)
        setCurrentLog(state.logId)
      }
    }
  }, [state])

  // 更新数据源列表
  const updateDataSource = () => {
    sourceRef.current.updateSourceList()
  }
  const updateLogs = () => {
    logRef.current?.updateLogList()
  }

  const selectLog = id => {
    setCurrentLog(id)
    setCurrentKey('3')
  }
  // Tab标签右边按钮
  const tabExtraBtn = () => {
    switch (currentKey) {
      case '1':
        return <DatasourceAdd updateDataSource={updateDataSource} />
      case '2':
        return (
          <Link to="/datasource/sync-task">
            <Button type="primary">添加同步任务</Button>
          </Link>
        )
      default:
        return
    }
  }
  return (
    <Datasource>
      {/* Tab栏及内容 */}
      <Tabs
        type="card"
        tabBarExtraContent={tabExtraBtn()}
        activeKey={currentKey}
        onTabClick={key => {
          if (key === '3') updateLogs()
          navigate('/datasource', { state: { key } })
        }}
        onChange={key => {
          setCurrentKey(key)
          setCurrentLog(null)
        }}>
        <TabPane tab="数据源管理" key="1">
          <DataSourceManage onRef={sourceRef} />
        </TabPane>
        <TabPane tab="同步配置" key="2">
          <DatasourceSyncView
            selectLog={id => selectLog(id)}
            page={currentSyncPage}
            page_size={currentSyncPageSize}
          />
        </TabPane>
        <TabPane tab="日志管理" key="3">
          <DatasourceLog
            onRef={logRef}
            logId={currentLog}
            page={currentLogPage}
            page_size={currentLogPageSize}
          />
        </TabPane>
      </Tabs>
    </Datasource>
  )
}
